All Classes and Interfaces

Class
Description
Auto-configuration imports for typical Spring GraphQL tests.
Annotation that can be applied to a test class to enable a GraphQlTester.
Annotation that can be applied to a test class to enable an HttpGraphQlTester.
Annotation to perform GraphQL tests focusing on GraphQL request execution without a Web layer, and loading only a subset of the application configuration.
Auto-configuration for GraphQlTester.
Auto-configuration for HttpGraphQlTester.